"""Module with message dialogs for convenient working with PyQt gui applications.

This module provides the message dialogs for convenient working with PyQt based gui applications.
"""
from PyQt5.QtWidgets import QMessageBox


def show_error(message):
    """Showing a Qt error dialog with a given message.

    Args:
        message (str): The message to show in the Qt error dialog.

    Returns:
        None
    """
    _show_message_box(message, QMessageBox.Critical)


def show_warning(message):
    """Showing a Qt warning dialog with a given message.

    Args:
        message (str): The message to show in the Qt warning dialog.

    Returns:
        None
    """
    _show_message_box(message, QMessageBox.Warning)


def _show_message_box(message, icon):
    """Helper function to show a message box with a given message and icon."""
    message_box = QMessageBox(icon=icon)
    message_box.setText(message)
    message_box.exec_()


def show_about(application_ui, application_name, application_version):
    """Showing a Qt about dialog of a given application with its name and version.

    Args:
        application_ui (type derived from QMainWindow): The application's pyqt ui.
        application_name (str): The application's name.
        application_version (str): The application's version number.

    Returns:
        None
    """
    QMessageBox.about(application_ui, application_name, "Version " + application_version)
