"""Module with base class for constant class attributes.

This module provides the base class to derive from for constant class attributes.
"""


class Constant(type):
    """Constant class as a base class for constant class attributes.

    This class provides base class for constant class attributes.
    """

    def __setattr__(cls, key, value):
        """Special method to make the attributes of the class deriving from Constant read-only. """
        raise AttributeError("cannot set attribute")

    def __str__(cls):
        """Special method to return a properly formatted string representing the class deriving from Constant."""
        constant_strings = []
        for constant in [constant for constant in dir(cls) if not constant.startswith("__")]:
            constant_strings.append(constant)
        return str(cls.__name__) + "(" + ", ".join(constant_strings) + ")"
